==> Glossary-0.6.7.tar.gz: Glossary/lang/en_US.php <==
<?php
$lang['areyousure_altercontent'] = 'Are you sure want to perform this operation?  Continuing will permanently alter your content';
$lang['filter_site_now'] = 'Filter Now';
$lang['friendlyname'] = 'Glossary / Dictionary';
$lang['postinstall'] = '<p>Be sure to set "Modify Glossary" permissions to use this module!</p>
<p>You\'ll almost certainly want to go in and change settings as well. I intentionally chose odd settings
in order to demonstrate features. But you will probably want more than five terms on a page, for example,
and you will want to delete my sample terms and categories.';
$lang['postuninstall'] = 'Successfully removed.';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['error'] = 'Error!';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['title_mod_prefs'] = 'Module Preferences';
$lang['title_mod_admin'] = 'Module Admin Panel';
$lang['title_term'] = 'Term';
$lang['title_definition'] = 'Definition';
$lang['column_definition'] = 'Definition';
$lang['title_default_template'] = 'Default Display Template';
$lang['title_default_single_term_template'] = 'Default template for linked Terms (if showing single term)';
$lang['title_filter_site'] = 'Automatically Filter Content Pages for Terms?';
$lang['title_filter_news'] = 'Filter News Articles for Terms?';
$lang['title_number_show'] = 'Number of terms to show per page';
$lang['title_default_number_show'] = 'Default number of terms to show per page';
$lang['title_filter_site_label'] = 'Activate all Terms on site? (warning - slows site performance)';
$lang['title_glossary_page'] = 'Glossary Page (target for active links)';
$lang['title_disable_prettyurls'] = 'Disable pretty urls for this module';
$lang['title_disable_prettyurls_label'] = 'Disable';
$lang['title_glossary_inline'] = 'Inline linked term display?';
$lang['title_show_termids'] = 'Show Term ID numbers in administration';
$lang['title_display_tab'] = 'Glossary Page Display Options';
$lang['title_single_term'] = 'Show linked term on its own page?';
$lang['title_single_term_label'] = 'Show single term (as opposed to full Glossary)';
$lang['title_wysiwyg_definitions'] = 'Use WYSIWYG for entering term definitions?';
$lang['title_wysiwyg_terms'] = 'Use WYSIWYG for entering terms?';
$lang['title_wysiwyg_terms_help'] = 'Please note that markup inside terms can interfere with alphabetizing and with activated terms!';
$lang['title_link_tab'] = 'Glossary Link Options';
$lang['title_admin_tab'] = 'Admin Panel Options';
$lang['title_filtering_tab'] = 'Site Term-filtering Options';
$lang['title_number_spining_chars']='Maximum number of characters to use of a term in the Glossary nav';
$lang['title_process_smarty'] = 'Process Smarty tags in definitions?';
$lang['filter_link'] = 'Link to Glossary Page';
$lang['column_term'] = 'Term';
$lang['column_termid'] = 'Term ID';
$lang['column_action'] = 'Action';
$lang['column_category'] = 'Category';
$lang['title_admin_panel'] = 'Glossary / Dictionary / FAQ';
$lang['title_term_list'] = 'Terms';
$lang['title_name'] = 'Name';
$lang['title_cats'] = 'Categories';
$lang['title_filter_category'] = 'Only show this category:';
$lang['title_all'] = 'All Categories';
$lang['column_template'] = 'Template Name';
$lang['title_template'] = 'Template Definition';
$lang['addterm'] = 'Add New Term';
$lang['termadded'] = 'Term has been added.';
$lang['termdeleted'] = 'Term has been deleted.';
$lang['edit'] = 'Edit Term';
$lang['no'] = 'No';
$lang['yes'] = 'Yes';
$lang['filter'] = 'Filter';
$lang['delete'] = 'Delete Term';
$lang['suredelete'] = 'Are you sure you want to delete the term %s?';
$lang['listterms'] = 'Manage Terms';
$lang['listtempl'] = 'Manage Templates';
$lang['listcats'] = 'Manage Categories';
$lang['addcat'] = 'Add Category';
$lang['editcat'] = 'Edit Category';
$lang['delcat'] = 'Delete Category';
$lang['manageprefs'] = 'Admin Preferences';
$lang['templatelist'] = 'Templates';
$lang['unknown_term'] = 'Unknown term %s requested.';
$lang['glossary_page_help'] = 'Select a page below that contains a tag to display glossary information, e.g., a page containing {cms_module module="Glossary"}';
$lang['glossary_prettyurls_help'] = 'Disabling pretty urls for this module may help if some of your terms have non alphanumeric characters or whitespace.';
$lang['glossary_inline_help'] = 'Use the following option if you wish to have your active-term definitions displayed in-line. This is mutually exclusive with linking to a Glossary Page';
$lang['title_glossary_inline_label'] = 'Display Inline';
$lang['notemplates'] = 'No templates in database.';
$lang['nocats'] = 'No categories in database.';
$lang['addtemplate'] = 'Add a template';
$lang['templateupdated'] = 'Template updated';
$lang['templatedeleted'] = 'Template deleted';
$lang['catupdated'] = 'Category updated';
$lang['catdeleted'] = 'Category deleted';
$lang['areyousure'] = 'Are you sure you want to delete %s?';
$lang['next'] = ' : Next &#187;';
$lang['prev'] = '&#171; Previous : ';
$lang['moddescription'] = 'This module allows you to create a list of terms and definitions for display. A term may be a word, a frequently asked question, or anything similar.';
$lang['changelog'] = '<ul>
<li>Version 0.6.6,  January 2009. Bug fixes, code refactoring, added "random" action, option to allow smarty tags in definitions, options for WYSIWYG.</li>
<li>Version 0.6.5,  January 2009. Bug fixes, now allows teplate specification to be name or id.</li>
<li>Version 0.6.4,  September 2008.  Adds glossary terms to the searchable content.  Bump minimum cms version to 1.4.1</li>
<li>Version 0.6.3,  March 2008.  Adds the ability to disable pretty urls for this module.  Bump minimum cms version to 1.2</li>
<li>Version 0.6.2.  December 2007.  Fixes a bug in preferences related to inline/non inline, bumps minimum cms version, Adds the RegisterModulePlugin call.</li>
<li>Version 0.6.1.  November 2007.  Adds functionality so that content never returns empty</li>
<li>Version 0.6. November 2007.  Adds a button to filter content and news on demand, splits it out into multiple files for reduced memory footprint.</li>
<li>Version 0.5.1. 28 Mar 2007.  Urls now validate. There ya go, Mr. InSiPiD.</li>
<li>Version 0.5. 8 November 2006. Removed pop-up window links, added inline display, and category filtering / requested features for InSiPiD.</li>
<li>Version 0.4. 7 November 2006. Updated for CMS MS 1.0.x, added features for InSiPiD.</li>
<li>Version 0.3. 24 October 2005. Bug fixes, new default template, more Admin configuration options.</li>
<li>Version 0.2. 20 October 2005. Initial Public Release.</li></ul>';
$lang['help_glossary_single']='Show single term';
$lang['help_glossary_tid']='Term ID to highlight/emphasize';
$lang['help_glossary_catid']='Restrict list to terms in category ID "catid"';
$lang['help_glossary_start']='Offset in list to start listing terms';
$lang['help_glossary_term']='Term to highlight/emphasize';
$lang['help_glossary_cat']='Restrict list to terms in category "cat"';
$lang['help_glossary_template']='Template name or ID to use to format terms';
$lang['help_glossary_term_count']='Number of terms to show on a page (overrides default setting from admin)';
$lang['help_glossary_show_nav']='Set to 0 to hide the pagination nav';
$lang['help_glossary_keyword']='Restrict to terms whose definitions contain "keyword"';
$lang['help_glossary_sort']='Sort order: currently only supports "alpha" or "random"';
$lang['help_glossary_no_pass_restrictions'] = 'To display a filtered or otherwise restricted list, but to have the expanded list not restricted, list the fields here (see example above)';

$lang['help'] = '<h3>What Does This Do?</h3>
<p>This allows the administrator to create a list of terms, which will appear on a page. Clicking on the term will expand it to include the definition.</p>
<h3>How Do I Use It</h3>
<h4>Standard Glossary Page</h4>
<p>Install it by placing the module in a page or template using the smarty tag &#123;cms_module module=\'Glossary\'}</p>
<p>You can have it start with a term expanded by passing a term=Term parameter, or passing a tid=term_id.</p>
<p>You can limit it to a specific category by passing a cat="Category" parameter.</p>
<p>You can override the default template by passing a template="template_id" parameter (use the numeric
id for the template, or the template name).</p>
<p>You can limit it to definitions containing a keyword by passing a keyword="keyword".</p>
<p>This module also will read the URL, and support specifications of "term" or "cat" on the URL. So, for example, you could have an URL like http://mysite/index.php?page=10&amp;term=myterm. If page 10 includes the Glossary module, it will expand the definition of "myterm".
<h4>Expanding Lists</h4>
<p>Sometimes, you will want a short list of terms, but have clicks on those terms to load a full list. For example, you might want three random terms in the sidebar, but clicking on those terms should show the selected term in a complete term list. To do this, set the "no_pass_restriction" variable.</p>
<p>For example, on your sidebar you want three random terms from category "foo". Clicking on a term should show a full, alphabetical list of category "foo" with the specific term open. Your tag for the sidebar will then look like:</p>
<p>&#123;cms_module module=\'Glossary\' cat=\'foo\' sort=\'random\' term_count=\'3\' no_pass_restriction=\'sort,term_count\'}</p>
<h4>WYSIWYG/Smarty</h4>
<p>In the admin, you can enable the WYSIWYG editor for terms and term definitions. Because of the way the system uses terms, it is not recommended
to use markup in the terms themselves. If you insist on doing it (and some people do, in fact, have good reasons to do so), be aware that site filtering will probably break, and the glossary page nav may be messed up.</p>
<p>You can also enable smarty processing on term definitions. This will permit you to do all sorts of wild stuff like self-linking and other smarty madness. Hey -- if you know enough to go on the black diamond run, you know the risks! I will say no more.</p>
<h3>Linked Terms</h3>
<h4>Overview</h4>
<p>You can make terms that show up in your pages link to their definitions, either "inline" (where it replaces the content of your page), or by linking to your main Glossary page. This is the "inline" option which you can set in the "Glossary Links Options" section of the Glossary Admin Prefs.</p>
<p>You can also choose to have links go to a page with only the definition of your term, and you can control the display of this by altering the template. This also set in "Glossary Links Options" section of the Glossary Admin Prefs.</p> 
<h4>Single Term</h4>
<p>You can tag specific words to be linked to the Glossary if you want, by placing the following tag in a page: &#123;cms_module module=\'Glossary\' action=\'def\' term=\'foo\'}, where you replace "foo" with a term that you have in your glossary.
<h4>Term Replacement / Site Filtering</h4>
<p>If you turn on site filtering, every instance of each of your terms that shows up on the site will become a link. Depending on the mode you choose in the admin,
this will either be a link to your main Glossary page or open to the term in question.</p>
<p>Site filtering is an intensive process, and will slow your site down somewhat. There is an alternate, faster implementation that I may use to replace the existing one,
if there are enough complaints. It\'s more complicated, and I\'m lazy, but given sufficient demand, I\'ll fix it.</p>
<h3>Credits</h3>
<p>Development of this module has been generously sponsored by Matt Hornsby.</p>
<p>Extensive testing, QA, ideas, and non-negotiable demands provided by Paul "InSiPiD" Noone and Daniel "Westis" Westergren.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the
module homepage at <a href="http://dev.cmsmadesimple.org/projects/glossary/">the CMS Developer Forge</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, SjG, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2006, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com">&lt;sjg@cmsmodules.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>

==> Glossary-1.0.tar.gz: Glossary/lang/en_US.php <==
<?php
$lang['info_filter_site'] = '<strong>Deprecated</strong> This functionality is deprecated, and will not be replaced.  It is recommended that you do not use this functionality';
$lang['areyousure_altercontent'] = 'Are you sure want to perform this operation?  Continuing will permanently alter your content';
$lang['filter_site_now'] = 'Filter Now';
$lang['friendlyname'] = 'Glossary / Dictionary';
$lang['postinstall'] = '<p>Be sure to set "Modify Glossary" permissions to use this module!</p>
<p>You\'ll almost certainly want to go in and change settings as well. I intentionally chose odd settings
in order to demonstrate features. But you will probably want more than five terms on a page, for example,
and you will want to delete my sample terms and categories.';
$lang['postuninstall'] = 'Successfully removed.';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['error'] = 'Error!';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['title_mod_prefs'] = 'Module Preferences';
$lang['title_mod_admin'] = 'Module Admin Panel';
$lang['title_term'] = 'Term';
$lang['title_tip'] = 'Tool-tip / Link title for term';
$lang['title_definition'] = 'Definition';
$lang['column_definition'] = 'Definition';
$lang['title_default_template'] = 'Default Display Template';
$lang['title_default_single_term_template'] = 'Default template for linked Terms (if showing single term)';
$lang['title_filter_site'] = 'Automatically Filter Content Pages for Terms?';
$lang['title_filter_news'] = 'Filter News Articles for Terms?';
$lang['title_number_show'] = 'Number of terms to show per page';
$lang['title_default_number_show'] = 'Default number of terms to show per page';
$lang['title_filter_site_label'] = 'Activate all Terms on site? (warning - slows site performance)';
$lang['title_glossary_page'] = 'Glossary Page (target for active links)';
$lang['title_disable_prettyurls'] = 'Disable pretty urls for this module';
$lang['title_disable_prettyurls_label'] = 'Disable';
$lang['title_glossary_inline'] = 'Inline linked term display?';
$lang['title_show_termids'] = 'Show Term ID numbers in administration';
$lang['title_display_tab'] = 'Glossary Page Display Options';
$lang['title_single_term'] = 'Show linked term on its own page?';
$lang['title_single_term_label'] = 'Show single term (as opposed to full Glossary)';
$lang['title_wysiwyg_definitions'] = 'Use WYSIWYG for entering term definitions?';
$lang['title_wysiwyg_terms'] = 'Use WYSIWYG for entering terms?';
$lang['title_wysiwyg_terms_help'] = 'Please note that markup inside terms can interfere with alphabetizing and with activated terms!';
$lang['title_link_tab'] = 'Glossary Link Options';
$lang['title_admin_tab'] = 'Admin Panel Options';
$lang['title_filtering_tab'] = 'Site Term-filtering Options';
$lang['title_number_spining_chars']='Maximum number of characters to use of a term in the Glossary nav';
$lang['title_process_smarty'] = 'Process Smarty tags in definitions?';
$lang['filter_link'] = 'Link to Glossary Page';
$lang['column_term'] = 'Term';
$lang['column_termid'] = 'Term ID';
$lang['column_action'] = 'Action';
$lang['column_select'] = 'Select';
$lang['column_category'] = 'Category';
$lang['title_admin_panel'] = 'Glossary / Dictionary / FAQ';
$lang['title_term_list'] = 'Terms';
$lang['title_name'] = 'Name';
$lang['title_cats'] = 'Categories';
$lang['title_filter_category'] = 'Only show this category:';
$lang['title_all'] = 'All Categories';
$lang['column_template'] = 'Template Name';
$lang['title_template'] = 'Template Definition';
$lang['addterm'] = 'Add New Term';
$lang['termadded'] = 'Term has been added.';
$lang['termdeleted'] = 'Term has been deleted.';
$lang['edit'] = 'Edit Term';
$lang['no'] = 'No';
$lang['yes'] = 'Yes';
$lang['filter'] = 'Filter';
$lang['delete'] = 'Delete Term';
$lang['delete_selected'] = 'Delete Selected Terms';
$lang['areyousure_deletemultiple'] = 'Are you sure you want to delete all of these terms?';
$lang['suredelete'] = 'Are you sure you want to delete the term %s?';
$lang['listterms'] = 'Manage Terms';
$lang['listtempl'] = 'Manage Templates';
$lang['listcats'] = 'Manage Categories';
$lang['addcat'] = 'Add Category';
$lang['editcat'] = 'Edit Category';
$lang['delcat'] = 'Delete Category';
$lang['manageprefs'] = 'Admin Preferences';
$lang['templatelist'] = 'Templates';
$lang['unknown_term'] = 'Unknown term %s requested.';
$lang['glossary_page_help'] = 'Select a page below that contains a tag to display glossary information, e.g., a page containing {cms_module module="Glossary"}';
$lang['glossary_prettyurls_help'] = 'Disabling pretty urls for this module may help if some of your terms have non alphanumeric characters or whitespace.';
$lang['glossary_inline_help'] = 'Use the following option if you wish to have your active-term definitions displayed in-line. This is mutually exclusive with linking to a Glossary Page';
$lang['title_glossary_inline_label'] = 'Display Inline';
$lang['notemplates'] = 'No templates in database.';
$lang['nocats'] = 'No categories in database.';
$lang['addtemplate'] = 'Add a template';
$lang['templateupdated'] = 'Template updated';
$lang['templatedeleted'] = 'Template deleted';
$lang['catupdated'] = 'Category updated';
$lang['catdeleted'] = 'Category deleted';
$lang['areyousure'] = 'Are you sure you want to delete %s?';
$lang['next'] = ' : Next &#187;';
$lang['prev'] = '&#171; Previous : ';
$lang['moddescription'] = 'This module allows you to create a list of terms and definitions for display. A term may be a word, a frequently asked question, or anything similar.';
$lang['changelog'] = '';
$lang['help_glossary_single']='Show single term.';
$lang['help_glossary_tid']='Term ID to highlight/emphasize.';
$lang['help_glossary_catid']='Restrict list to terms in category ID "catid".';
$lang['help_glossary_start']='Offset in list to start listing terms.';
$lang['help_glossary_term']='Term to highlight/emphasize.';
$lang['help_glossary_cat']='Restrict list to terms in category "cat".';
$lang['help_glossary_template']='Template name or ID to use to format terms.';
$lang['help_glossary_term_count']='Number of terms to show on a page (overrides default setting from admin).';
$lang['help_glossary_show_nav']='Set to 0 to hide the pagination nav.';
$lang['help_glossary_keyword']='Restrict to terms whose definitions contain "keyword".';
$lang['help_glossary_sort']='Sort order: currently only supports "alpha", "random" and "create_date".  Random sort order may only refresh occasionally if smarty caching is enabled.';
$lang['help_glossary_no_pass_restrictions'] = 'To display a filtered or otherwise restricted list, but to have the expanded list not restricted, list the fields here (see example above)';
$lang['help_glossary_target']='Page alias to target to display terms';
?>
